@@ -3,13 +3,14 @@ from bread import layout as layout
 from bread.layout.components.datatable import DataTableColumn
 from bread.utils import get_concrete_instance
 from bread.utils.links import Link
-from bread.utils.urls import reverse
+from bread.utils.urls import reverse, reverse_model
 from bread.views import BrowseView, BulkAction
 from bread.views.browse import delete as breaddelete
 from bread.views.browse import export as breadexport
 from bread.views.browse import restore as breadrestore
 from django import forms
 from django.db.models import Q
+from django.http import HttpResponseRedirect
 from django.utils.html import mark_safe
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy
@@ -31,6 +32,27 @@ def bulkrestore(request, qs):
         person.save()
 
 
+def bulkaddtag(request, qs):
+    return _redirect_to_tag_operation(qs, "add")
+
+
+def bulkremovetag(request, qs):
+    return _redirect_to_tag_operation(qs, "remove")
+
+
+def _redirect_to_tag_operation(qs, operation):
+    return HttpResponseRedirect(
+        reverse_model(
+            models.Person,
+            "bulk-tag-operation",
+            query={
+                "operation": operation,
+                "persons": [str(person.id) for person in qs],
+            },
+        )
+    )
+
+
 def export(request, queryset):
     # Fields which are filtered should also be displayed in columns
     form = PersonBrowseView.FilterForm({"status": ["active"], **request.GET})
@@ -58,16 +80,19 @@ def export(request, queryset):
         return hg.F(lambda c: getattr(get_concrete_instance(c["row"]), field, ""))
 
     # insert last_name and first_name
-    name_field = [getattr(i, "sortingname", i) for i in columns].index(
-        "default_sorting_name"
-    )
-    columns.insert(
-        name_field + 1,
-        DataTableColumn(
-            layout.ObjectFieldLabel("first_name", models.NaturalPerson),
-            get_from_concret_object("first_name"),
-        ),
-    )
+    try:
+        name_field = [getattr(i, "sortingname", i) for i in columns].index(
+            "default_sorting_name"
+        )
+        columns.insert(
+            name_field + 1,
+            DataTableColumn(
+                layout.ObjectFieldLabel("first_name", models.NaturalPerson),
+                get_from_concret_object("first_name"),
+            ),
+        )
+    except ValueError:
+        pass
 
     return breadexport(queryset=queryset, columns=columns)
 
@@ -130,6 +155,18 @@ class PersonBrowseView(BrowseView):
         ),
     ]
     bulkactions = (
+        BulkAction(
+            "add-tag",
+            label=_("Add tag"),
+            iconname="add",
+            action=bulkaddtag,
+        ),
+        BulkAction(
+            "remove-tag",
+            label=_("Remove tag"),
+            iconname="subtract",
+            action=bulkremovetag,
+        ),
         BulkAction(
             "delete",
             label=_("Delete"),
