@@ -6,6 +6,9 @@ class MailerIntegrationConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
     name = "basxconnect.mailer_integration"
 
+    def ready(self):
+        import basxconnect.mailer_integration.signal_handlers  # noqa
+
 
 @register()
 def check_mailchimp_settings(app_configs, **kwargs):
